==> tellico_2.3.8+dfsg.1.orig.tar.xz: tellico-2.3.8/src/commands/modifyentries.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_MODIFYENTRIES_H
#define TELLICO_MODIFYENTRIES_H

#include "../datavectors.h"

#include <QUndoCommand>

namespace Tellico {
  namespace Command {

/**
 * @author Robby Stephenson
 */
class ModifyEntries : public QUndoCommand {

public:
  ModifyEntries(Data::CollPtr coll, const Data::EntryList& oldEntries,
                const Data::EntryList& newEntries, const QStringList& modifiedFields);
  ModifyEntries(QUndoCommand* parent, Data::CollPtr coll, const Data::EntryList& oldEntries,
                const Data::EntryList& newEntries, const QStringList& modifiedFields);

  virtual void redo();
  virtual void undo();

private:
  void swapValues();

  Data::CollPtr m_coll;
  Data::EntryList m_oldEntries;
  Data::EntryList m_entries;
  QStringList m_modifiedFields;
  bool m_needToSwap : 1;
};

  } // end namespace
}

#endif

==> tellico_3.5.3.orig.tar.xz: tellico-3.5.3/src/commands/modifyentries.h <==
/***************************************************************************
    Copyright (C) 2005-2009 Robby Stephenson <robby@periapsis.org>
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or         *
 *   modify it under the terms of the GNU General Public License as        *
 *   published by the Free Software Foundation; either version 2 of        *
 *   the License or (at your option) version 3 or any later version        *
 *   accepted by the membership of KDE e.V. (or its successor approved     *
 *   by the membership of KDE e.V.), which shall act as a proxy            *
 *   defined in Section 14 of version 3 of the license.                    *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 *                                                                         *
 ***************************************************************************/

#ifndef TELLICO_MODIFYENTRIES_H
#define TELLICO_MODIFYENTRIES_H

#include "../datavectors.h"

#include <QUndoCommand>

namespace Tellico {
  namespace Command {

/**
 * @author Robby Stephenson
 */
class ModifyEntries : public QUndoCommand {

public:
  ModifyEntries(Data::CollPtr coll, const Data::EntryList& oldEntries,
                const Data::EntryList& newEntries, const QStringList& modifiedFields);
  ModifyEntries(QUndoCommand* parent, Data::CollPtr coll, const Data::EntryList& oldEntries,
                const Data::EntryList& newEntries, const QStringList& modifiedFields);

  virtual void redo() Q_DECL_OVERRIDE;
  virtual void undo() Q_DECL_OVERRIDE;

private:
  void swapValues();

  Data::CollPtr m_coll;
  Data::EntryList m_oldEntries;
  Data::EntryList m_entries;
  QStringList m_modifiedFields;
  bool m_needToSwap : 1;
};

  } // end namespace
}

#endif
